@@ -4,13 +4,16 @@ use strict;
 
 use Carp();
 
+use Rose::HTML::Object::Errors qw(:field);
+use Rose::HTML::Object::Messages qw(:field);
+
 use Rose::HTML::Form::Field;
 use Rose::HTML::Form::Field::Collection;
 our @ISA = qw(Rose::HTML::Form::Field Rose::HTML::Form::Field::Collection);
 
 use Rose::HTML::Form::Constants qw(FF_SEPARATOR);
 
-our $VERSION = '0.52';
+our $VERSION = '0.54';
 
 # Multiple inheritence never quite works out the way I want it to...
 Rose::HTML::Form::Field::Collection->import_methods
@@ -255,15 +258,16 @@ sub validate
 
     foreach my $field ($self->fields)
     {
+      no warnings 'uninitialized';
       unless(length $field->input_value_filtered)
       {
-        push(@missing, $field->label || $field->name);
+        push(@missing, sub { $field->label || $field->name });
       }
     }
 
     if(@missing)
     {
-      $self->error('Missing ' . join(', ', @missing));
+      $self->error_id(FIELD_REQUIRED, { missing => \@missing });
       return 0;
     }
   }
@@ -271,8 +275,46 @@ sub validate
   return $self->SUPER::validate(@_);
 }
 
+sub message_for_error_id
+{
+  my($self, %args) = @_;
+
+  my $error_id  = $args{'error_id'};
+  my $msg_class = $args{'msg_class'};
+  my $args      = $args{'args'} || [];
+
+  no warnings 'uninitialized';
+  if($error_id == FIELD_REQUIRED)
+  {
+    my $msg = $msg_class->new(args => $args);
+
+    if((ref $args eq 'HASH' && keys %$args) || (ref $args eq 'ARRAY' && @$args))
+    {
+      $msg->id(FIELD_REQUIRED_SUBFIELD);
+    }
+    else
+    {
+      $msg->id(FIELD_REQUIRED_GENERIC);
+    }
+
+    return $msg;
+  }
+
+  return undef;
+}
+
 1;
 
+__DATA__
+
+[% LOCALE en %]
+
+FIELD_REQUIRED_SUBFIELD = "Missing [@missing]."
+
+[% LOCALE xx %]
+
+FIELD_REQUIRED_SUBFIELD = "Missing [@missing( : )]."
+
 __END__
 
 =head1 NAME
