@@ -52,6 +52,13 @@ sub xhtml_field
 
 sub short_label { shift->html_attr('label', @_) }
 
+sub name
+{
+  my($self) = shift;
+  $self->local_name(shift)  if(@_);
+  return $self->fq_name;
+}
+
 1;
 
 __END__
@@ -184,4 +191,4 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2006 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
