@@ -2,6 +2,8 @@ package Rose::HTML::Form::Field::Time::Seconds;
 
 use strict;
 
+use Rose::HTML::Object::Errors qw(:time);
+
 use Rose::HTML::Form::Field::Text;
 our @ISA = qw(Rose::HTML::Form::Field::Text);
 
@@ -23,7 +25,7 @@ sub validate
 
   unless($value =~ /^\d\d?$/ && $value >= 0 && $value <= 59)
   {
-    $self->error('Invalid seconds');
+    $self->add_error_id(TIME_INVALID_SECONDS);
     return 0;
   }
 
@@ -33,6 +35,12 @@ sub validate
 
 1;
 
+__DATA__
+
+[% LOCALE en %]
+
+TIME_INVALID_MINUTE = "Invalid seconds."
+
 __END__
 
 =head1 NAME
